@@ -18,11 +18,17 @@
 
 """This module allows to connect to a MySQL database."""
 import json
-from typing import Dict, Optional, Tuple
+from typing import TYPE_CHECKING, Dict, Optional, Tuple, Union
 
 from airflow.hooks.dbapi import DbApiHook
 from airflow.models import Connection
 
+if TYPE_CHECKING:
+    from mysql.connector.abstracts import MySQLConnectionAbstract
+    from MySQLdb.connections import Connection as MySQLdbConnection
+
+MySQLConnectionTypes = Union['MySQLdbConnection', 'MySQLConnectionAbstract']
+
 
 class MySqlHook(DbApiHook):
     """
@@ -37,6 +43,9 @@ class MySqlHook(DbApiHook):
     "aws_default" connection to get the temporary token unless you override
     in extras.
     extras example: ``{"iam":true, "aws_conn_id":"my_aws_conn"}``
+
+    :param schema: The MySQL database schema to connect to.
+    :param connection: The :ref:`MySQL connection id <howto/connection:mysql>` used for MySQL credentials.
     """
 
     conn_name_attr = 'mysql_conn_id'
@@ -50,20 +59,33 @@ class MySqlHook(DbApiHook):
         self.schema = kwargs.pop("schema", None)
         self.connection = kwargs.pop("connection", None)
 
-    def set_autocommit(self, conn: Connection, autocommit: bool) -> None:  # noqa: D403
-        """MySql connection sets autocommit in a different way."""
-        conn.autocommit(autocommit)
-
-    def get_autocommit(self, conn: Connection) -> bool:  # noqa: D403
+    def set_autocommit(self, conn: MySQLConnectionTypes, autocommit: bool) -> None:
         """
-        MySql connection gets autocommit in a different way.
+        The MySQLdb (mysqlclient) client uses an `autocommit` method rather
+        than an `autocommit` property to set the autocommit setting
+
+        :param conn: connection to set autocommit setting
+        :param autocommit: autocommit setting
+        :rtype: None
+        """
+        if hasattr(conn.__class__, 'autocommit') and isinstance(conn.__class__.autocommit, property):
+            conn.autocommit = autocommit
+        else:
+            conn.autocommit(autocommit)
+
+    def get_autocommit(self, conn: MySQLConnectionTypes) -> bool:
+        """
+        The MySQLdb (mysqlclient) client uses a `get_autocommit` method
+        rather than an `autocommit` property to get the autocommit setting
 
         :param conn: connection to get autocommit setting from.
-        :type conn: connection object.
         :return: connection autocommit setting
         :rtype: bool
         """
-        return conn.get_autocommit()
+        if hasattr(conn.__class__, 'autocommit') and isinstance(conn.__class__.autocommit, property):
+            return conn.autocommit
+        else:
+            return conn.get_autocommit()
 
     def _get_conn_config_mysql_client(self, conn: Connection) -> Dict:
         conn_config = {
@@ -122,7 +144,7 @@ class MySqlHook(DbApiHook):
 
         return conn_config
 
-    def get_conn(self):
+    def get_conn(self) -> MySQLConnectionTypes:
         """
         Establishes a connection to a mysql database
         by extracting the connection configuration from the Airflow connection.
@@ -133,9 +155,7 @@ class MySqlHook(DbApiHook):
 
         :return: a mysql connection object
         """
-        conn = self.connection or self.get_connection(
-            getattr(self, self.conn_name_attr)
-        )  # pylint: disable=no-member
+        conn = self.connection or self.get_connection(getattr(self, self.conn_name_attr))
 
         client_name = conn.extra_dejson.get('client', 'mysqlclient')
 
@@ -146,10 +166,10 @@ class MySqlHook(DbApiHook):
             return MySQLdb.connect(**conn_config)
 
         if client_name == 'mysql-connector-python':
-            import mysql.connector  # pylint: disable=no-name-in-module
+            import mysql.connector
 
             conn_config = self._get_conn_config_mysql_connector_python(conn)
-            return mysql.connector.connect(**conn_config)  # pylint: disable=no-member
+            return mysql.connector.connect(**conn_config)
 
         raise ValueError('Unknown MySQL client name provided!')
 
@@ -186,17 +206,13 @@ class MySqlHook(DbApiHook):
         conn.commit()
 
     @staticmethod
-    def _serialize_cell(
-        cell: object, conn: Optional[Connection] = None
-    ) -> object:  # pylint: disable=signature-differs   # noqa: D403
+    def _serialize_cell(cell: object, conn: Optional[Connection] = None) -> object:
         """
-        MySQLdb converts an argument to a literal
+        The package MySQLdb converts an argument to a literal
         when passing those separately to execute. Hence, this method does nothing.
 
         :param cell: The cell to insert into the table
-        :type cell: object
         :param conn: The database connection
-        :type conn: connection object
         :return: The same cell
         :rtype: object
         """
@@ -231,19 +247,15 @@ class MySqlHook(DbApiHook):
             This depends on the mysql client library used.
 
         :param table: The table were the file will be loaded into.
-        :type table: str
         :param tmp_file: The file (name) that contains the data.
-        :type tmp_file: str
         :param duplicate_key_handling: Specify what should happen to duplicate data.
             You can choose either `IGNORE` or `REPLACE`.
 
             .. seealso::
                 https://dev.mysql.com/doc/refman/8.0/en/load-data.html#load-data-duplicate-key-handling
-        :type duplicate_key_handling: str
         :param extra_options: More sql options to specify exactly how to load the data.
 
             .. seealso:: https://dev.mysql.com/doc/refman/8.0/en/load-data.html
-        :type extra_options: str
         """
         conn = self.get_conn()
         cursor = conn.cursor()
